# OBP_Reliability_Pillar

OBP_Reliability_Pillar package can be used to get the compliance details of Operational Best Practices for AWS Well Architected Reliability Pillar.

Release Notes:
# v0.0.8
1. Added following compliance checks:
   - DbInstanceBackupEnabled
   - S3BucketDefaultLockEnabled
   - LambdaInsideVpc
   - GuarddutyEnabledCentralized
   - DynamodbPitrEnabled
   - RedshiftClusterMaintenancesettingsCheck
2. Minor bug fixes

# v0.0.7
1. Added following compliance checks:
   - Elastic Search In VPC only
   - ELB deletion protection enabled
   - Instance in VPC
   - Lambda dlq check

# v0.0.4
1. Added Description column on Compliance Data set
2. Added method for S3 Bucket replication compliance
3. Fixes bugs
